Documentation
¶
Overview ¶
Package examples is a generated GoMock package.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MockMailService ¶
type MockMailService struct {
// contains filtered or unexported fields
}
MockMailService is a mock of MailService interface.
func NewMockMailService ¶
func NewMockMailService(ctrl *gomock.Controller) *MockMailService
NewMockMailService creates a new mock instance.
func (*MockMailService) EXPECT ¶
func (m *MockMailService) EXPECT() *MockMailServiceMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockMailService) SendMail ¶
func (m *MockMailService) SendMail() error
SendMail mocks base method.
type MockMailServiceMockRecorder ¶
type MockMailServiceMockRecorder struct {
// contains filtered or unexported fields
}
MockMailServiceMockRecorder is the mock recorder for MockMailService.
func (*MockMailServiceMockRecorder) SendMail ¶
func (mr *MockMailServiceMockRecorder) SendMail() *gomock.Call
SendMail indicates an expected call of SendMail.
type MockUserRepository ¶
type MockUserRepository struct {
// contains filtered or unexported fields
}
MockUserRepository is a mock of UserRepository interface.
func NewMockUserRepository ¶
func NewMockUserRepository(ctrl *gomock.Controller) *MockUserRepository
NewMockUserRepository creates a new mock instance.
func (*MockUserRepository) EXPECT ¶
func (m *MockUserRepository) EXPECT() *MockUserRepositoryMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockUserRepository) GetUser ¶
func (m *MockUserRepository) GetUser(arg0 string) (User, error)
GetUser mocks base method.
func (*MockUserRepository) StoreUser ¶
func (m *MockUserRepository) StoreUser(arg0 User) error
StoreUser mocks base method.
type MockUserRepositoryMockRecorder ¶
type MockUserRepositoryMockRecorder struct {
// contains filtered or unexported fields
}
MockUserRepositoryMockRecorder is the mock recorder for MockUserRepository.
type UserController ¶
type UserController struct {
Mailer MailService
Repository UserRepository
}
System under test.